@@ -89,7 +89,7 @@ class MarketData:
         if os.path.exists(filename):
             os.remove(filename)
         df = self.reader.update_df(
-            filename, self.get_dividends(**kwargs), C.EX)
+            filename, self.get_dividends(**kwargs), C.EX, C.DATE_FMT)
         self.writer.update_csv(filename, df)
 
     def get_splits(self, symbol, timeframe='max'):
@@ -121,7 +121,8 @@ class MarketData:
         filename = self.finder.get_splits_path(symbol, self.provider)
         if os.path.exists(filename):
             os.remove(filename)
-        df = self.reader.update_df(filename, self.get_splits(**kwargs), C.EX)
+        df = self.reader.update_df(
+            filename, self.get_splits(**kwargs), C.EX, C.DATE_FMT)
         self.writer.update_csv(filename, df)
 
     def standardize_ohlc(self, symbol, df):
@@ -160,7 +161,8 @@ class MarketData:
         filename = self.finder.get_ohlc_path(symbol, self.provider)
         if os.path.exists(filename):
             os.remove(filename)
-        df = self.reader.update_df(filename, self.get_ohlc(**kwargs), C.TIME)
+        df = self.reader.update_df(
+            filename, self.get_ohlc(**kwargs), C.TIME, C.DATE_FMT)
         self.writer.update_csv(filename, df)
 
     def get_social_sentiment(self, symbol, timeframe='max'):
@@ -260,8 +262,9 @@ class MarketData:
                 symbol, date, self.provider)
             if os.path.exists(filename):
                 os.remove(filename)
+            save_fmt = f'{C.DATE_FMT} {C.TIME_FMT}'
             df = self.reader.update_df(
-                filename, df, C.TIME)
+                filename, df, C.TIME, save_fmt)
             self.writer.update_csv(filename, df)
     # def handle_request(self, url, err_msg):
 
@@ -498,10 +501,14 @@ class Polygon(MarketData):
                        'vw': 'average', 'n': 'trades'}
 
             df = pd.DataFrame(response).rename(columns=columns)
-            df['date'] = pd.to_datetime(
-                df['date'], unit='ms').dt.tz_localize(
-                'UTC').dt.tz_convert(
-                C.TZ).dt.tz_localize(None)
+            if symbol.find('X%3A') == 0:
+                df['date'] = pd.to_datetime(
+                    df['date'], unit='ms')
+            else:
+                df['date'] = pd.to_datetime(
+                    df['date'], unit='ms').dt.tz_localize(
+                    'UTC').dt.tz_convert(
+                    C.TZ).dt.tz_localize(None)
             df = self.standardize_ohlc(symbol, df)
             return self.reader.data_in_timeframe(df, C.TIME, timeframe)
 
@@ -514,7 +521,7 @@ class Polygon(MarketData):
             if dates == []:
                 raise Exception(f'No dates in timeframe: {timeframe}.')
 
-            for date in dates:
+            for idx, date in enumerate(dates):
                 response = self.client.stocks_equities_aggregates(
                     symbol, min, 'minute', from_=date, to=date,
                     unadjusted=False
@@ -529,11 +536,18 @@ class Polygon(MarketData):
                            'l': 'low', 'c': 'close', 'v': 'volume',
                            'vw': 'average', 'n': 'trades'}
                 df = pd.DataFrame(response).rename(columns=columns)
-                df['date'] = pd.to_datetime(
-                    df['date'], unit='ms').dt.tz_localize(
-                    'UTC').dt.tz_convert(
+                if symbol.find('X%3A') == 0:
+                    df['date'] = pd.to_datetime(
+                        df['date'], unit='ms')
+                    if idx != len(dates) - 1:
+                        sleep(15)
+                else:
+                    df['date'] = pd.to_datetime(
+                        df['date'], unit='ms').dt.tz_localize(
+                        'UTC').dt.tz_convert(
                         C.TZ).dt.tz_localize(None)
                 df = self.standardize_ohlc(symbol, df)
+                df = df[df[C.TIME].dt.strftime(C.DATE_FMT) == date]
                 yield self.reader.data_in_timeframe(
                     df, C.TIME, timeframe
                 )
